# Generated by Django 4.1.5 on 2023-03-03 02:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('project_center', '0006_projectstage_display'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='company',
            options={'verbose_name': 'Project Company', 'verbose_name_plural': 'Project Companies'},
        ),
        migrations.AlterModelOptions(
            name='user',
            options={'verbose_name': 'Project User', 'verbose_name_plural': 'Project Users'},
        ),
        migrations.AddField(
            model_name='project',
            name='date',
            field=models.DateTimeField(blank=True, help_text='Start Date', null=True, verbose_name='Start Date'),
        ),
    ]
